@@ -211,7 +211,7 @@ def is_equal_ls_value_simple_value(ls_value, val):
     elif isinstance(val, FileValue):
         return ls_value.file_value == val
     elif isinstance(val, BlobValue):
-        return ls_value.blob_value == BlobValue(val.value, val.comments)
+        return  BlobValue(ls_value.blob_value, ls_value.comments) == val
     elif isinstance(val, clob):
         return ls_value.clob_value == str(val)
     elif type(val) == str:
@@ -301,7 +301,7 @@ def make_ls_value(value_cls, value_kind, val, recorded_by):
     if isinstance(val, FileValue):
         value = value_cls(ls_type="fileValue", ls_kind=value_kind, recorded_by=recorded_by,
                           file_value=val, unit_kind=unit_kind)
-    if isinstance(val, BlobValue):
+    elif isinstance(val, BlobValue):
         value = value_cls(
             ls_type="blobValue",
             ls_kind=value_kind,
@@ -682,6 +682,8 @@ class BlobValue(object):
         return full_file_path
 
     def __eq__(self, other: object) -> bool:
+        if other is None:
+            return False
         return self.value == other.value and self.comments == other.comments
 
     def as_dict(self) -> Dict[str, Any]:
@@ -1570,7 +1572,8 @@ class SimpleLsThing(BaseModel):
     ROW_NUM_KEY = 'row number'
 
     def __init__(self, ls_type=None, ls_kind=None, code_name=None, names={}, ids={}, aliases={}, metadata={}, results={}, links=[], recorded_by=None,
-                 preferred_label_kind=None, state_tables=defaultdict(dict), ls_thing=None):
+                 preferred_label_kind=None, state_tables=defaultdict(dict), ls_thing=None, client=None):
+        self._client = client
         self.preferred_label_kind = preferred_label_kind
         # if ls_thing passed in, just parse from it and ignore the rest
         if ls_thing:
@@ -1686,6 +1689,14 @@ class SimpleLsThing(BaseModel):
                 parsed_links.append(link)
         self.links = parsed_links
 
+    def set_client(self, client):
+        """
+        Set ACAS database client.
+        :param client: ACAS database client.
+        :type client: acasclient.client
+        """
+        self._client = client
+
     def _convert_values_to_objects(self, values_dict, state):
         values_obj_dict = {}
         ls_values = []
@@ -1841,7 +1852,9 @@ class SimpleLsThing(BaseModel):
         if not ls_kind:
             ls_kind = cls.ls_kind
         camel_case_dict = client.get_ls_thing(ls_type, ls_kind, code_name)
-        return cls(ls_thing=LsThing.from_camel_dict(data=camel_case_dict))
+        simple_ls_thing = cls(ls_thing=LsThing.from_camel_dict(data=camel_case_dict))
+        simple_ls_thing.set_client(client=client)
+        return simple_ls_thing
 
     @classmethod
     def save_list(cls, client, models):
